Select areas that used an intervention in their last year with data
last_used.RdReturns the grouping columns for groups where `var` was greater than zero in the most recent year that has a (non-`NA`) value.
last_used.RdReturns the grouping columns for groups where `var` was greater than zero in the most recent year that has a (non-`NA`) value.