Set a change point
set_change_point.RdSets a variable to a target value at a specific year (optionally restricted to a set of sites). Errors if it would overwrite an existing non-`NA` value.
set_change_point.RdSets a variable to a target value at a specific year (optionally restricted to a set of sites). Errors if it would overwrite an existing non-`NA` value.